% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/advanced.R
\name{mdb_hexdump}
\alias{mdb_hexdump}
\title{Hexdump MDB File (mdb-hexdump mimic)}
\usage{
mdb_hexdump(path, pagenumber = NULL, page_size = 4096L, n = 256L)
}
\arguments{
\item{path}{Path to file.}

\item{pagenumber}{Optional page index (0-based) like \verb{mdb-hexdump file [pagenumber]}.}

\item{page_size}{Page size in bytes (default 4096 for modern Jet/ACE).}

\item{n}{Number of bytes to emit.}
}
\value{
Single hexadecimal string.
}
\description{
Hexdump MDB File (mdb-hexdump mimic)
}
\examples{
db <- mdbr:::.mdb_example_nwind_path()
if (nzchar(db)) {
  mdb_hexdump(db, n = 16)
}
}
