% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/advanced.R
\name{mdb_import}
\alias{mdb_import}
\title{Import CSV Into MDB (mdb-import mimic)}
\usage{
mdb_import(path, table, csvfile, header_lines = 0L, delimiter = ",")
}
\arguments{
\item{path}{Path to \code{.mdb}/\code{.accdb} file.}

\item{table}{Table name.}

\item{csvfile}{CSV file path.}

\item{header_lines}{Equivalent to \code{-H/--header} skipped lines.}

\item{delimiter}{Equivalent to \code{-d/--delimiter}.}
}
\value{
No return; always errors in read-only mode.
}
\description{
\code{mdb-import(1)} writes to MDB files. This package is read-only, so this
function validates CLI-like options and then errors.
}
\keyword{internal}
