% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/advanced.R
\name{mdb_ver}
\alias{mdb_ver}
\title{Return MDB File Format Or MDB Tools Version}
\usage{
mdb_ver(path = NULL, version = FALSE)
}
\arguments{
\item{path}{Optional database path. When omitted, the wrapper returns the
mdbtools package version for backward compatibility.}

\item{version}{Logical, equivalent to \code{-M/--version}.}
}
\value{
Single character string with file format or mdbtools version.
}
\description{
\code{mdb-ver} will return a single line of output corresponding to the program
that produced the file: \code{JET3} (for files produced by Access 97), \code{JET4}
(Access 2000, XP and 2003), \code{ACE12} (Access 2007), \code{ACE14} (Access 2010),
\code{ACE15} (Access 2013), or \code{ACE16} (Access 2016).
}
\examples{
mdb_ver()
db <- mdbr:::.mdb_example_nwind_path()
if (nzchar(db)) {
  mdb_ver(db)
}
}
